

Exporting slides to PDF
=======================

The to my knowledge best way to export slides to PDF is using
https://github.com/astefanutti/decktape.

First install the tool following https://github.com/astefanutti/decktape#install,
then you can export slides, e.g.::

  $ decktape http://cicero.xyz/v3/remark/0.14.0/github.com/coderefinery/social-coding/master/talk.md/ my-slides.pdf
